<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="he">
<context>
    <name>AboutDialog</name>
    <message>
        <source>A simple, user-friendly Jabber/XMPP client</source>
        <translation>לקוח Jabber/XMPP פשוט ונוח לשימוש</translation>
    </message>
    <message>
        <source>License:</source>
        <translation>רישיון:</translation>
    </message>
    <message>
        <source>View source code online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report problems</source>
        <translation>דיווח על בעיות</translation>
    </message>
</context>
<context>
    <name>AccountSecurity</name>
    <message>
        <source>Account Security</source>
        <translation>אבטחת החשבון</translation>
    </message>
    <message>
        <source>Allow to add additional devices using the login QR code but never show the password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t show password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Neither allow to add additional devices using the login QR code nor show the password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t expose password in any way</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccountTransferPage</name>
    <message>
        <source>Transfer account to another device</source>
        <translation>העברת החשבון למכשיר אחר</translation>
    </message>
    <message>
        <source>Scan the QR code or enter the credentials as text on another device to log in on it.

Attention:
Never show this QR code to anyone else. It would allow unlimited access to your account!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat address:</source>
        <translation>כתובת שיחה:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>ססמה:</translation>
    </message>
    <message>
        <source>Hide QR code</source>
        <translation>הסתרת קוד QR</translation>
    </message>
    <message>
        <source>Show as QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide text</source>
        <translation>הסתרת הטקסט</translation>
    </message>
    <message>
        <source>Show as text</source>
        <translation>הצגה כטקסט</translation>
    </message>
    <message>
        <source>Copy chat address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangePassword</name>
    <message>
        <source>Change password</source>
        <translation>שינוי הססמה</translation>
    </message>
    <message>
        <source>Current password:</source>
        <translation>הססמה הנוכחית:</translation>
    </message>
    <message>
        <source>New password:</source>
        <translation>הססמה החדשה:</translation>
    </message>
    <message>
        <source>New password (repeat):</source>
        <translation>הססמה החדשה (שנית):</translation>
    </message>
    <message>
        <source>New passwords do not match.</source>
        <translation>הססמות החדשות לא תואמות.</translation>
    </message>
    <message>
        <source>Current password is invalid.</source>
        <translation>הססמה הנוכחית אינה תקינה.</translation>
    </message>
    <message>
        <source>You need to be connected to change your password.</source>
        <translation type="vanished">יש להתחבר על מנת לשנות את הססמה.</translation>
    </message>
    <message>
        <source>After changing your password, you will need to reenter it on all your other devices.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>שינוי</translation>
    </message>
    <message>
        <source>Password changed successfully</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to change password: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatMessage</name>
    <message>
        <source>Spoiler</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download</source>
        <translation>הורדה</translation>
    </message>
</context>
<context>
    <name>ChatMessageContextMenu</name>
    <message>
        <source>Copy message</source>
        <translation>העתקת ההודעה</translation>
    </message>
    <message>
        <source>Edit message</source>
        <translation>עריכת ההודעה</translation>
    </message>
    <message>
        <source>Copy download URL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quote message</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatPage</name>
    <message>
        <source>Compose message</source>
        <translation type="vanished">חיבור הודעה</translation>
    </message>
    <message>
        <source>Send a spoiler message</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unmute notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mute notifications</source>
        <translation>השתקת ההתרעות</translation>
    </message>
    <message>
        <source>View profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search</source>
        <translation>חיפוש</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="vanished">סגירה</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="vanished">כל הקבצים</translation>
    </message>
    <message>
        <source>Close message search bar</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChatPageSendingPane</name>
    <message>
        <source>Spoiler hint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close spoiler hint field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Compose message</source>
        <translation type="unfinished">חיבור הודעה</translation>
    </message>
</context>
<context>
    <name>ClientWorker</name>
    <message>
        <source>Your account could not be deleted from the server. Therefore, it was also not removed from this app: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CommonEncoderSettings</name>
    <message>
        <source>Very low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Low</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>High</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Very high</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Constant quality</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Constant bit rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Average bit rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Two pass</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfirmationPage</name>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
</context>
<context>
    <name>ConnectionSettings</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change</source>
        <translation type="unfinished">שינוי</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">ביטול</translation>
    </message>
    <message>
        <source>Connection settings could not be changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection settings changed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CustomConnectionSettings</name>
    <message>
        <source>Hostname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The hostname must not contain blank spaces</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisablePasswordDisplay</name>
    <message>
        <source>Remove password</source>
        <translation type="vanished">הסרת הססמה</translation>
    </message>
    <message>
        <source>Don&apos;t expose your password in any way</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will neither be shown as plain text nor included in the login QR code anymore.
You won&apos;t be able to use the login via QR code without entering your password again because this action cannot be undone!
Consider storing the password somewhere else if you want to use your account on another device.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t expose password in any way</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DisablePlainTextPasswordDisplay</name>
    <message>
        <source>Do not show password</source>
        <translation type="vanished">לא להציג את הססמה</translation>
    </message>
    <message>
        <source>Don&apos;t show your password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your password will not be shown anymore but still exposed via the login QR code.
You won&apos;t be able to see your password again because this action cannot be undone!
Consider storing the password somewhere else if you want to use your account on another device without the login QR code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Don&apos;t show password</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadJob</name>
    <message>
        <source>Could not save file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download failed: %1</source>
        <translation>ההורדה נכשלה: %1</translation>
    </message>
</context>
<context>
    <name>EmojiPicker</name>
    <message>
        <source>Favorites</source>
        <translation type="vanished">מועדפים</translation>
    </message>
    <message>
        <source>People</source>
        <translation type="vanished">אנשים</translation>
    </message>
    <message>
        <source>Nature</source>
        <translation type="vanished">טבע</translation>
    </message>
    <message>
        <source>Food</source>
        <translation type="vanished">אוכל</translation>
    </message>
    <message>
        <source>Activity</source>
        <translation type="vanished">פעילות</translation>
    </message>
    <message>
        <source>Travel</source>
        <translation type="vanished">טיול</translation>
    </message>
    <message>
        <source>Objects</source>
        <translation type="vanished">אובייקטים</translation>
    </message>
    <message>
        <source>Symbols</source>
        <translation type="vanished">סימנים</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation type="vanished">דגלים</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">חיפוש</translation>
    </message>
    <message>
        <source>Search emoji</source>
        <translation type="vanished">חיפוש אימוג׳י</translation>
    </message>
</context>
<context>
    <name>EmptyChatPage</name>
    <message>
        <source>Please select a chat to start messaging</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GlobalDrawer</name>
    <message>
        <source>About</source>
        <translation>על אודות</translation>
    </message>
    <message>
        <source>Invite friends</source>
        <translation>הזמנת חברים</translation>
    </message>
    <message>
        <source>Invitation link copied to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>הגדרות</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation>לא מחובר/ת</translation>
    </message>
    <message>
        <source>Online</source>
        <translation>מחובר/ת</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>בהתחברות…</translation>
    </message>
    <message>
        <source>Switch device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Kaidan</name>
    <message>
        <source>The link will be opened after you have connected.</source>
        <extracomment>The link is an XMPP-URI (i.e. &apos;xmpp:kaidan@muc.kaidan.im?join&apos; for joining a chat)</extracomment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocalAccountRemoval</name>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your account will be removed from this app.
Your password will be deleted, make sure it is stored in a password manager or you know it!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>הסרה</translation>
    </message>
</context>
<context>
    <name>LoginPage</name>
    <message>
        <source>Log in</source>
        <translation>התחברות</translation>
    </message>
    <message>
        <source>Log in to your XMPP account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation>בהתחברות…</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation type="vanished">התחברות</translation>
    </message>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginSettingsPage</name>
    <message>
        <source>Connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The connection settings will be saved permanently after the first successful login. If they don&apos;t work, you&apos;ll get back to the login page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable custom connection settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Port:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hostname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MediaRecorder</name>
    <message>
        <source>Default</source>
        <translation>ברירת מחדל</translation>
    </message>
</context>
<context>
    <name>MediaUtils</name>
    <message>
        <source>Take picture</source>
        <translation>צילום תמונה</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation>הקלטת סרטון</translation>
    </message>
    <message>
        <source>Record voice</source>
        <translation>הקלטת קול</translation>
    </message>
    <message>
        <source>Send location</source>
        <translation>שליחת מיקום</translation>
    </message>
    <message>
        <source>Choose file</source>
        <translation>בחירת קובץ</translation>
    </message>
    <message>
        <source>Choose image</source>
        <translation>בחירת תמונה</translation>
    </message>
    <message>
        <source>Choose video</source>
        <translation>בחירת סרטון</translation>
    </message>
    <message>
        <source>Choose audio file</source>
        <translation>בחירת קובץ שמע</translation>
    </message>
    <message>
        <source>Choose document</source>
        <translation>בחירת מסמך</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>כל הקבצים</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>תמונות</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>סרטונים</translation>
    </message>
    <message>
        <source>Audio files</source>
        <translation>קובצי שמע</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>מסמכים</translation>
    </message>
    <message>
        <source>%1 (%2)</source>
        <translation>%1 (%2)</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished">שמע</translation>
    </message>
    <message>
        <source>Document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation type="unfinished">תמונה</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished">סרטון</translation>
    </message>
    <message>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Message</name>
    <message>
        <source>Spoiler</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageHandler</name>
    <message>
        <source>Message could not be sent.</source>
        <translation>לא היה ניתן לשלוח את ההודעה.</translation>
    </message>
    <message>
        <source>Message correction was not successful.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageModel</name>
    <message>
        <source>Pending</source>
        <translation>בהמתנה</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delivered</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation>שגיאה</translation>
    </message>
</context>
<context>
    <name>MultimediaSettings</name>
    <message>
        <source>Multimedia Settings</source>
        <translation>הגדרות מולטימדיה</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>הגדרה</translation>
    </message>
    <message>
        <source>Image Capture</source>
        <translation>לכידת תמונה</translation>
    </message>
    <message>
        <source>Audio Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Video Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>מצלמה</translation>
    </message>
    <message>
        <source>Audio input</source>
        <translation>קלט שמע</translation>
    </message>
    <message>
        <source>Container</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image</source>
        <translation>תמונה</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>שמע</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>סרטון</translation>
    </message>
    <message>
        <source>Codec</source>
        <translation>מפענח</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>רזולוציה</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>איכות</translation>
    </message>
    <message>
        <source>Sample Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Frame Rate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ready</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Initializing…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>לא זמין/ה</translation>
    </message>
    <message>
        <source>Recording…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paused</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewMedia</name>
    <message>
        <source>Initializing…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unavailable</source>
        <translation>לא זמין/ה</translation>
    </message>
    <message>
        <source>Recording… %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paused %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordRemovalPage</name>
    <message>
        <source>Remove password</source>
        <translation type="unfinished">הסרת הססמה</translation>
    </message>
    <message>
        <source>You can decide to only not show your password for &lt;b&gt;%1&lt;/b&gt; as text anymore or to remove it completely from the account transfer. If you remove your password completely, you won&apos;t be able to use the account transfer via scanning without entering your password because it is also removed from the QR code.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not show password as text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove completely</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Mark as read</source>
        <translation>סימון כנקרא</translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Free for chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Away</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not disturb</source>
        <translation type="unfinished">נא לא להפריע</translation>
    </message>
    <message>
        <source>Away for longer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished">לא מחובר/ת</translation>
    </message>
</context>
<context>
    <name>QmlUtils</name>
    <message>
        <source>Do not disturb</source>
        <translation type="vanished">נא לא להפריע</translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="vanished">לא מחובר/ת</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="vanished">שגיאה</translation>
    </message>
    <message>
        <source>Invalid username or password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot connect to the server. Please check your internet connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server doesn&apos;t support secure connections.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error while trying to connect securely.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentification protocol not supported by the server.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This server does not support registration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The server is offline or blocked by a firewall.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The connection could not be refreshed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The internet access is not permitted. Please check your system&apos;s internet access configuration.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not connect to the server. Please check your internet connection or your server name.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is online</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is typing…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 paused typing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeGenerator</name>
    <message>
        <source>Generating the QR code failed: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeOnboardingPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="unfinished">סריקת קוד QR</translation>
    </message>
    <message>
        <source>Show explanation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation type="unfinished">המשך ללא קוד QR</translation>
    </message>
    <message>
        <source>Scan the QR code from your existing device to transfer your account.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished">בהתחברות…</translation>
    </message>
    <message>
        <source>This QR code is not a valid login QR code.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeScanner</name>
    <message>
        <source>The camera format &apos;%1&apos; is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no camera available.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your camera is busy.
Try to close other applications using the camera.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QrCodeScannerPage</name>
    <message>
        <source>Scan QR code</source>
        <translation type="vanished">סריקת קוד QR</translation>
    </message>
    <message>
        <source>Scan</source>
        <translation type="vanished">סריקה</translation>
    </message>
    <message>
        <source>Continue without QR code</source>
        <translation type="vanished">המשך ללא קוד QR</translation>
    </message>
    <message>
        <source>Connecting…</source>
        <translation type="vanished">בהתחברות…</translation>
    </message>
</context>
<context>
    <name>RegistrationLoginDecisionPage</name>
    <message>
        <source>Set up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Register a new account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use an existing account</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RemoteAccountDeletion</name>
    <message>
        <source>Delete account completely</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Your account will be deleted completely, which means from this app and from the server.
You will not be able to use your account again!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished">מחיקה</translation>
    </message>
</context>
<context>
    <name>RosterAddContactSheet</name>
    <message>
        <source>Add new contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will also send a request to access the presence of the contact.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Jabber-ID:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>user@example.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Optional message:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tell your chat partner who you are.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">ביטול</translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterManager</name>
    <message>
        <source>Could not add contact, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not remove contact, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not rename contact, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterPage</name>
    <message>
        <source>Connecting…</source>
        <translation type="unfinished">בהתחברות…</translation>
    </message>
    <message>
        <source>Contacts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add new contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Offline</source>
        <translation type="unfinished">לא מחובר/ת</translation>
    </message>
    <message>
        <source>Search contacts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterRemoveContactSheet</name>
    <message>
        <source>Delete contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>מחיקה</translation>
    </message>
    <message>
        <source>Do you really want to delete the contact &lt;b&gt;%1&lt;/b&gt; from your contact list?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RosterRenameContactSheet</name>
    <message>
        <source>Rename contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>ביטול</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>שינוי שם</translation>
    </message>
</context>
<context>
    <name>SendMediaSheet</name>
    <message>
        <source>Caption</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">ביטול</translation>
    </message>
    <message>
        <source>Send</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ServerListModel</name>
    <message>
        <source>Custom server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No limitation</source>
        <extracomment>Unlimited file size for uploading files
----------
Deletion of message history saved on server</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 days</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsContent</name>
    <message>
        <source>Change password</source>
        <translation type="unfinished">שינוי הססמה</translation>
    </message>
    <message>
        <source>Changes your account&apos;s password. You will need to re-enter it on your other devices.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multimedia Settings</source>
        <translation type="unfinished">הגדרות מולטימדיה</translation>
    </message>
    <message>
        <source>Configure photo, video and audio recording settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished">הגדרות</translation>
    </message>
    <message>
        <source>Account security</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from Kaidan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove account from this app</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete account</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete account from the server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Connection Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure the hostname and port to connect to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure whether this device can be used to log in on another device</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsPage</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished">הגדרות</translation>
    </message>
</context>
<context>
    <name>StartPage</name>
    <message>
        <source>Enjoy free communication on every device!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Let&apos;s start</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SubRequestAcceptSheet</name>
    <message>
        <source>Subscription Request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You received a subscription request by &lt;b&gt;%1&lt;/b&gt;. If you accept it, the account will have access to your presence status.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Accept</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploadManager</name>
    <message>
        <source>Could not send file, as a result of not being connected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Message could not be sent.</source>
        <translation type="unfinished">לא היה ניתן לשלוח את ההודעה.</translation>
    </message>
</context>
<context>
    <name>UserProfilePage</name>
    <message>
        <source>Profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show QR code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove contact</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Online devices</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VCardModel</name>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About</source>
        <translation type="unfinished">על אודות</translation>
    </message>
    <message>
        <source>Email</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Birthday</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Website</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
